# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from datetime import datetime
from typing_extensions import Literal

from ...._models import BaseModel

__all__ = ["BetaManagedAgentsAgentThreadContextCompactedEvent"]


class BetaManagedAgentsAgentThreadContextCompactedEvent(BaseModel):
    """Indicates that context compaction (summarization) occurred during the session."""

    id: str
    """Unique identifier for this event."""

    processed_at: datetime
    """A timestamp in RFC 3339 format"""

    type: Literal["agent.thread_context_compacted"]
